# Supplementary materials to paper:
# "Climatic variation in Africa and Europe has combined effects on timing of spring migration in a long-distance migrant bird: a case study on Willow Warbler Phylloscopus trochilus"
# Magdalena Remisiewicz, Les G. Underhill

## R script by Magdalena Remisiewicz, Les G. Underhill & Eva Poliska (7 Dec 2019)

## Corresponding Author:  Magdalena Remisiewicz 
## Email address: magdalena.remisiewicz@biol.ug.edu.pl

library (abind)
library (DescTools)
library (base64enc)
library (Hmisc)
library (plyr)
library(graphics)
library (mgcv)
library (data.table)
library (lattice)
library (lme4)
library (MASS)
library (car)
library(heplots)
library (MuMIn)

getwd()
dat <- read.csv2("RemisiewiczUnderhill_Data_GLMs_PHYLUS_BKS_PeerJ_v2.csv", sep = ";",  header = T)

names(dat) # standardised data 
#== Table 2: Pearsons correlation coefficients between the 13 climate indices and the year in 19822017 #####
# using standardised data 
# results for Table 2 
library(corrplot)
library(ggcorrplot)
library(xtable)

temp <- dat
options(max.print = .Machine$integer.max) #for larger correlation matrices
temp.rcorr = rcorr(as.matrix(temp))
temp.coeff = temp.rcorr$r
temp.p = temp.rcorr$P

write.csv2(temp.coeff, file = "WW_Pearson r.csv") 
write.csv2(temp.p, file = "WW_Pearson p.csv")

#== Fig.3 and Table S3: REGRESSION OF dates of percentiles (BK10, BK50, BK 90) on the Year #####
# using raw (non-standardised) dates of percentiles
Year <- dat$Year
YearN <- dat$YearN
BKAARaw <- dat$BKAARaw
BK5Raw <- dat$BK5Raw
BK10Raw <- dat$BK10Raw
BK25Raw <- dat$BK25Raw
BK50Raw <- dat$BK50Raw
BK75Raw <- dat$BK75Raw
BK90Raw <- dat$BK90Raw
BK95Raw <- dat$BK95Raw
BKLength5_95Raw <- dat$BKLength5_95Raw
BKLength10_90Raw <- dat$BKLength10_90Raw

regBK5 <- lm (BK5Raw ~ YearN, data=dat)
summary (regBK5)
regBK5$co

regBK10 <- lm (BK10Raw ~ YearN, data=dat)
summary (regBK10)
regBK10$co

regBK25 <- lm (BK25Raw ~ YearN, data=dat)
summary (regBK25)
regBK25$co

regBK50 <- lm (BK50Raw ~ YearN, data=dat)
summary (regBK50)
regBK50$co

regBK75 <- lm (BK75Raw ~ YearN, data=dat)
summary (regBK75)
regBK75$co

regBK90 <- lm (BK90Raw ~ YearN, data=dat)
summary (regBK90)
regBK90$co

regBK95 <- lm (BK95Raw ~ YearN, data=dat)
summary (regBK95)
regBK95$co

regLength10_90 <- lm (BKLength10_90Raw ~ YearN, data=dat)
summary (regLength10_90)
regLength10_90$co

regBKAA <- lm (BKAARaw ~ YearN, data=dat)
summary (regBKAA)
regBKAA$co


fullmodel <- lm(BKAA ~ YearN #Year
                + LEB_APR_MAY + NAO_APR_MAY + SCAND_APR_MAY +  + #condition during spring arrival
                  + NAO_NOV_MAR + SAH_NOV_MAR + IOD_NOV_MAR + SOI_NOV_MAR #conditions non-breeding during stay Nov-Mar
                + NAO_AUG_OCT + SAH_AUG_OCT + IOD_AUG_OCT + SOI_AUG_OCT #conditions during migration south to non-breeding grounds Aug  Oct
                + NAO_JUN_JUL + SCAND_JUN_JUL 
                - 1 # no Intercept, alternative notation +0#conditions during previous breeding season
                , data = dat) #conditions during previous breeding season
summary (fullmodel) 



#= MODEL SELECTION: multiple regression models with Year and 13 climate variables ====
#== 1st METHOD: "all-subsets selection" of the best model according to AICc ====  
require(MuMIn)
# Table S5: full model with Year + 13 climate variables
full.model <- lm(BKAA ~ YearN #Year
                + LEB_APR_MAY + NAO_APR_MAY + SCAND_APR_MAY +  + #condition during spring arrival
                + NAO_NOV_MAR + SAH_NOV_MAR + IOD_NOV_MAR + SOI_NOV_MAR #conditions non-breeding during stay Nov-Mar
                + NAO_AUG_OCT + SAH_AUG_OCT + IOD_AUG_OCT + SOI_AUG_OCT #conditions during migration south to non-breeding grounds Aug  Oct
                + NAO_JUN_JUL + SCAND_JUN_JUL 
                - 1 # no Intercept, alternative notation +0#conditions during previous breeding season
                , data = dat) #conditions during previous breeding season
summary (full.model) # results presented in Table S5

#=== Fig.S2: diagnostics of the full  model - plots of residuals ==== 
windows(18,18) #square figure window
par(mfrow = c(2, 2))  # Split the plotting panel into a 2 x 2 grid
plot(full.model)  
# plots of residuals presented at Fig. S2

#=== Table S6: "all-subsets selection" of the best model by AICc using "dredge"====
options(na.action = "na.fail")
results <- dredge(full.model)
# the dredge function fits all combinations
results
names (results)

# best model
subset(results, delta == 0)
# best suppported models with delta AICc < 2
subset(results, delta < 2)

res.subset <- subset(results, delta < 2)
res.subset
write.csv2(res.subset,"Models delta AICc 0-2.csv", row.names = F)

sel.table <- as.data.frame (res.subset)[15:19]
head (sel.table)

sel.table[,2:3]<- round(sel.table[,2:3],4)
sel.table[,4:5]<- round(sel.table[,4:5],4)
sel.table
names(sel.table)[1] = "K"
sel.table$Model <- rownames(sel.table)
sel.table
write.csv2(sel.table,"Table_Models delta AICc 0-2.csv", row.names = F)
# results presented in Table S6

#== 2nd METHOD:stepwise backward selection of the best model according to AIC ====
full.model <- lm(BKAA ~ YearN #Year
              + LEB_APR_MAY + NAO_APR_MAY + SCAND_APR_MAY +  + #condition during spring arrival
              + NAO_NOV_MAR + SAH_NOV_MAR + IOD_NOV_MAR + SOI_NOV_MAR #conditions non-breeding during stay Nov-Mar
              + NAO_AUG_OCT + SAH_AUG_OCT + IOD_AUG_OCT + SOI_AUG_OCT #conditions during migration south to non-breeding grounds Aug  Oct
              + NAO_JUN_JUL + SCAND_JUN_JUL 
              - 1 # no Intercept, alternative notation +0#conditions during previous breeding season
            , data = dat) #conditions during previous breeding season
summary (full.model) 
VIF (full.model)  # Variance Inflation Factor

step(full.model, direction = "backward") 
#stepwise backward selection of the best model according to AIC

#=== Table 3: best model ===========
bestmodel <- lm(formula = BKAA ~ LEB_APR_MAY + NAO_APR_MAY + NAO_NOV_MAR + 
                  SAH_NOV_MAR + IOD_AUG_OCT + SOI_AUG_OCT + SCAND_JUN_JUL - 
                  1, data = dat)
summary (bestmodel) 
VIF (bestmodel)  # Variance Inflation Factor
etasq(bestmodel) #partial R2 coefficient for each factor

#=== Fig.S3: best model diagnostics: plots of residuals ==== 
windows(18,18) #square figure window
par(mfrow = c(2, 2))  # Split the plotting panel into a 2 x 2 grid
plot(bestmodel)  
# plots of residuals presented at Fig. S3

#=== Fig.S4: best model diagnostics: residuals from models with 6 variables against the 7th variable =============
#=====MODEL with LEB_APR_MAY as 7th variable ===========
m_noLEB_APR_MAY <- lm(BKAA ~ #Year
                          + NAO_APR_MAY + #condition during spring arrival
                          + NAO_NOV_MAR + SAH_NOV_MAR#conditions non-breeding during stay Nov-Mar
                        + IOD_AUG_OCT + SOI_AUG_OCT #conditions during migration south to non-breeding grounds Aug  Oct
                        + SCAND_JUN_JUL #conditions during previous breeding season
                        - 1 # no Intercept
                        , data = dat) #conditions during previous breeding season
summary (m_noLEB_APR_MAY) 
residuals (m_noLEB_APR_MAY) 

windows(18,18) #square figure window
#par(mar=c(4,5,4,1))
#par(mfrow = c(3,3)) #to plot all 9 figures as one

plot (resid(m_noLEB_APR_MAY) ~ dat$LEB_APR_MAY, pch = 16, col = "black", xlab="Standardised Leba Apr-May mean temperature", ylab="Residuals from model with 6 climate factors", xlim=c(-3,3), ylim=c(-2,2))# FIRST y , THEN x

#=====MODEL with NAO_APR_MAY as 7th variable ===========
m_noNAO_APR_MAY <- lm(BKAA ~ #Year
                          + LEB_APR_MAY + #condition during spring arrival
                          + NAO_NOV_MAR + SAH_NOV_MAR#conditions non-breeding during stay Nov-Mar
                          + IOD_AUG_OCT + SOI_AUG_OCT #conditions during migration south to non-breeding grounds Aug  Oct
                          + SCAND_JUN_JUL #conditions during previous breeding season
                          - 1 # no Intercept
                          , data = dat) #conditions during previous breeding season
summary (m_noNAO_APR_MAY) 
residuals (m_noNAO_APR_MAY) 

windows(18,18) #square figure
plot (resid(m_noNAO_APR_MAY) ~ dat$NAO_APR_MAY, pch = 16, col = "black", xlab="Standardised NAO index Apr-May", ylab="Residuals from model with 6 climate factors", xlim=c(-3,3), ylim=c(-2,2))# FIRST y , THEN x

#=====MODEL with NAO_NOV_MAR as 7th variable ===========
m_noNAO_NOV_MAR <- lm(BKAA ~ #Year
                          + LEB_APR_MAY + NAO_APR_MAY #condition during spring arrival
                          + SAH_NOV_MAR#conditions non-breeding during stay Nov-Mar
                          + IOD_AUG_OCT + SOI_AUG_OCT #conditions during migration south to non-breeding grounds Aug  Oct
                          + SCAND_JUN_JUL #conditions during previous breeding season
                          - 1 # no Intercept
                          , data = dat) #conditions during previous breeding season
summary (m_noNAO_NOV_MAR) 
residuals (noNAO_NOV_MAR) 

windows(18,18) #square figure
plot (resid(m_noNAO_NOV_MAR) ~ dat$NAO_NOV_MAR, pch = 16, col = "black", xlab="Standardised NAO index Nov-Mar", ylab="Residuals from model with 6 climate factors", xlim=c(-3,3), ylim=c(-2,2))# FIRST y , THEN x

#=====MODEL with SAH_NOV_MAR as 7th variable ===========
m_noSAH_NOV_MAR <- lm(BKAA ~ #Year
                            + LEB_APR_MAY + NAO_APR_MAY #condition during spring arrival
                          + NAO_NOV_MAR #conditions non-breeding during stay Nov-Mar
                          + IOD_AUG_OCT + SOI_AUG_OCT #conditions during migration south to non-breeding grounds Aug  Oct
                          + SCAND_JUN_JUL #conditions during previous breeding season
                          - 1 # no Intercept
                          , data = dat) #conditions during previous breeding season
summary (m_noSAH_NOV_MAR) 
residuals (m_noSAH_NOV_MAR) 

windows(18,18) #square figure
#par(mar=c(4,5,4,1))
#par(mfrow = c(3,3))
plot (resid(m_noSAH_NOV_MAR) ~ dat$SAH_NOV_MAR, pch = 16, col = "black", xlab="Standardised SAH index Nov-Mar", ylab="Residuals from model with 6 climate factors", xlim=c(-3,3), ylim=c(-2,2))# FIRST y , THEN x

#=====MODEL with IOD_AUG_OCT as 7th variable ===========
m_noIOD_AUG_OCT <- lm(BKAA ~ #Year
                            + LEB_APR_MAY + NAO_APR_MAY #condition during spring arrival
                          + NAO_NOV_MAR + SAH_NOV_MAR#conditions non-breeding during stay Nov-Mar
                          + SOI_AUG_OCT #conditions during migration south to non-breeding grounds Aug  Oct
                          + SCAND_JUN_JUL #conditions during previous breeding season
                          - 1 # no Intercept
                          , data = dat) #conditions during previous breeding season
summary (m_noIOD_AUG_OCT) 

windows(18,18) #square figure
#par(mar=c(4,5,4,1))
#par(mfrow = c(3,3))
plot (resid(m_noIOD_AUG_OCT) ~ dat$IOD_AUG_OCT, pch = 16, col = "black", xlab="Standardised IOD Aug-Oct", ylab="Residuals from model with 6 climate factors", xlim=c(-3,3), ylim=c(-2,2))# FIRST y , THEN x

#=====MODEL with SOI_AUG_OCT as 7th variable ===========
m_noSOI_AUG_OCT <- lm(BKAA ~ #Year
                          + LEB_APR_MAY + NAO_APR_MAY #condition during spring arrival
                          + NAO_NOV_MAR + SAH_NOV_MAR#conditions non-breeding during stay Nov-Mar
                          + IOD_AUG_OCT #conditions during migration south to non-breeding grounds Aug  Oct
                          + SCAND_JUN_JUL #conditions during previous breeding season
                          - 1 # no Intercept
                          , data = dat) #conditions during previous breeding season
summary (m_noSOI_AUG_OCT) 

windows(18,18) #square figure
plot (resid(m_noSOI_AUG_OCT) ~ dat$SOI_AUG_OCT, pch = 16, col = "black", xlab="Standardised SOI Aug-Oct", ylab="Residuals from model with 6 climate factors", xlim=c(-3,3), ylim=c(-2,2))# FIRST y , THEN x

#=====MODEL with SOI_AUG_OCT as 7th variable ===========
m_noSCAND_JUN_JUL <- lm(BKAA ~ #Year
                          + LEB_APR_MAY + NAO_APR_MAY #condition during spring arrival
                          + NAO_NOV_MAR + SAH_NOV_MAR#conditions non-breeding during stay Nov-Mar
                          + SOI_AUG_OCT + IOD_AUG_OCT #conditions during migration south to non-breeding grounds Aug  Oct
                          #conditions during previous breeding season
                          - 1 # no Intercept
                          , data = dat) #conditions during previous breeding season
summary (m_noSCAND_JUN_JUL) 

windows(18,18) #square figure
plot (resid(m_noSCAND_JUN_JUL) ~ dat$SCAND_JUN_JUL, pch = 16, col = "black", xlab="Standardised SCAND index Jun-Jul", ylab="Residuals from model with 6 climate factors", xlim=c(-3,3), ylim=c(-2,2))# FIRST y , THEN x



# Figure S3
#== Fig.4: REGRESSIONS of BKAA (standardised data) on seven climate variables selected by the best model ##### 
reg <- lm (BKAA ~ LEB_APR_MAY, data=dat)# FIRST y , THEN x
summary (reg)
reg$co
windows(18,18) #square figure window
plot (BKAA ~ LEB_APR_MAY, pch = 16, col = "black", data=dat)# FIRST y , THEN x
abline (coef(reg)[1], coef(reg)[2], col = "black")

reg <- lm (BKAA ~ SCAND_JUN_JUL, data=dat)# FIRST y , THEN x
summary (reg)
reg$co
windows(18,18) #square figure window
plot (BKAA ~ SCAND_JUN_JUL, pch = 16, col = "slategray", data=dat)# FIRST y , THEN x
abline (coef(reg)[1], coef(reg)[2], col=2)

reg <- lm (BKAA ~ NAO_APR_MAY, data=dat)# FIRST y , THEN x
summary (reg)
reg$co
windows(18,18) #square figure window
plot (BKAA ~ NAO_APR_MAY, pch = 16, col = "slategray", data=dat)# FIRST y , THEN x
abline (coef(reg)[1], coef(reg)[2], col=2)

reg <- lm (BKAA ~ IOD_AUG_OCT, data=dat)# FIRST y , THEN x
summary (reg)
reg$co
windows(18,18) #square figure window
plot (BKAA ~ IOD_AUG_OCT, pch = 16, col = "slategray", data=dat)# FIRST y , THEN x
abline (coef(reg)[1], coef(reg)[2], col=2)

reg <- lm (BKAA ~ NAO_NOV_MAR, data=dat)# FIRST y , THEN x
summary (reg)
reg$co
windows(18,18) #square figure window
plot (BKAA ~ NAO_NOV_MAR, pch = 16, col = "slategray", data=dat)# FIRST y , THEN x
abline (coef(reg)[1], coef(reg)[2], col=2)

reg <- lm (BKAA ~ SOI_AUG_OCT, data=dat)# FIRST y , THEN x
summary (reg)
reg$co
windows(18,18) #square figure window
plot (BKAA ~ SOI_AUG_OCT, pch = 16, col = "slategray", data=dat)# FIRST y , THEN x
abline (coef(reg)[1], coef(reg)[2], col=2)

reg <- lm (BKAA ~ SAH_NOV_MAR, data=dat)# FIRST y , THEN x
summary (reg)
reg$co
windows(18,18) #square figure window
plot (BKAA ~ SAH_NOV_MAR, pch = 16, col = "slategray", data=dat)# FIRST y , THEN x
abline (coef(reg)[1], coef(reg)[2], col=2)

###===== comparison of linear and quadratic relationships of AA and the climate indices ====###
regAA.lin <- lm (BKAA ~ NAO_APR_MAY, data=dat)
summary (regAA.lin)
regAA.lin$co

regAA.quad <- lm (BKAA ~ (NAO_APR_MAY)^2, data=dat)
summary (regAA.quad)
regAA.quad$co


###==== ADDITIONAL ANALYSES TO ANSWER THE REVIEW =========
#=== MODELS INCLUDING LOCAL PRECIPITATION IN LEBA ========
#== full model with Year + 13 climate variables 
# and standardised Leba Apr-May precipitation (LEB_PREC_Apr_May) 
# and interaction with temperature LEB_PREC_Apr_May*LEB_APR_MAY
#==== 1st METHOD: "all-subsets selection" of the best model according to AICc ====  
require(MuMIn)
# model with all parameters
fullmodel.prec <- lm(BKAA ~ YearN #Year
                        + LEB_PREC_Apr_May + LEB_APR_MAY + LEB_PREC_Apr_May*LEB_APR_MAY # local conditions in April-May
                        + NAO_APR_MAY + SCAND_APR_MAY  #conditions during spring arrival
                        + NAO_NOV_MAR + SAH_NOV_MAR + IOD_NOV_MAR + SOI_NOV_MAR #conditions non-breeding during stay Nov-Mar
                        + NAO_AUG_OCT + SAH_AUG_OCT + IOD_AUG_OCT + SOI_AUG_OCT #conditions during migration south to non-breeding grounds Aug  Oct
                        + NAO_JUN_JUL + SCAND_JUN_JUL 
                        - 1 # no Intercept, alternative notation +0#conditions during previous breeding season
                        , data = dat) #conditions during previous breeding season
summary (fullmodel.prec) 
VIF (fullmodel.prec)  # Variance Inflation Factor

options(na.action = "na.fail")
results <- dredge(fullmodel.prec)
# the dredge function fits all combinations
results
names (results)

# best model
subset(results, delta == 0)
bestmodel1.prec <- lm(formula = BKAA ~ 
                      + LEB_APR_MAY + LEB_PREC_Apr_May + NAO_APR_MAY 
                      + SAH_AUG_OCT + IOD_AUG_OCT + SCAND_JUN_JUL
                       - 1, data = dat)
summary (bestmodel1.prec) 
VIF (bestmodel1.prec)  # Variance Inflation Factor
etasq(bestmodel1.prec) #partial R2 coefficient for each factor

# best suppported models with delta AICc < 2
subset(results, delta < 2)

res.subset <- subset(results, delta < 2)
res.subset
write.csv2(res.subset,"Models delta AICc 0-2prec.csv", row.names = F)

sel.table <- as.data.frame (res.subset)[15:19]
head (sel.table)

sel.table[,2:3]<- round(sel.table[,2:3],4)
sel.table[,4:5]<- round(sel.table[,4:5],4)
sel.table
names(sel.table)[1] = "K"
sel.table$Model <- rownames(sel.table)
sel.table
write.csv2(sel.table,"Table_Models with precipitation delta AICc 0-2.csv", row.names = F)
#==== 2nd METHOD:stepwise backward selection of the best model according to AIC ====
step(fullmodel.prec, direction = "backward") 

bestmodel1.prec <- lm(formula = BKAA ~ 
                      + LEB_APR_MAY + LEB_PREC_Apr_May 
                      + NAO_APR_MAY 
                      + SAH_AUG_OCT + IOD_AUG_OCT
                      + SCAND_JUN_JUL
                      - 1, data = dat)

bestmodel2.prec <- lm(formula = BKAA ~ 
                        LEB_PREC_Apr_May + LEB_APR_MAY + 
                        NAO_APR_MAY + 
                        SAH_NOV_MAR + SAH_AUG_OCT + 
                        IOD_AUG_OCT + SOI_AUG_OCT + SCAND_JUN_JUL - 
                        1, data = dat)
summary (bestmodel2.prec) 
VIF (bestmodel2.prec)  # Variance Inflation Factor
etasq(bestmodel2.prec) #partial R2 coefficient for each factor

#=== COMPARISON OF MODELS with AA against climate variables as linear and quadratic terms ====
m1LEB_APR_MAY <- lm(BKAA ~ LEB_APR_MAY - 1, data = dat) 
m2LEB_APR_MAY <- lm(BKAA ~ poly (LEB_APR_MAY, 2) - 1, data = dat) 
AICc(m1LEB_APR_MAY, m2LEB_APR_MAY)

m1NAO_APR_MAY <- lm(BKAA ~ NAO_APR_MAY - 1, data = dat) 
m2NAO_APR_MAY <- lm(BKAA ~ poly (NAO_APR_MAY, 2) - 1, data = dat) 
AICc(m1NAO_APR_MAY, m2NAO_APR_MAY)

m1NAO_APR_MAY <- lm(BKAA ~ NAO_APR_MAY - 1, data = dat) 
m2NAO_APR_MAY <- lm(BKAA ~ poly (NAO_APR_MAY, 2) - 1, data = dat) 
AICc(m1NAO_APR_MAY, m2NAO_APR_MAY)

m1SCAND_APR_MAY <- lm(BKAA ~ SCAND_APR_MAY - 1, data = dat) 
m2SCAND_APR_MAY <- lm(BKAA ~ poly (SCAND_APR_MAY, 2) - 1, data = dat) 
AICc(m1SCAND_APR_MAY, m2SCAND_APR_MAY)

m1NAO_NOV_MAR <- lm(BKAA ~ NAO_NOV_MAR - 1, data = dat) 
m2NAO_NOV_MAR <- lm(BKAA ~ poly (NAO_NOV_MAR, 2) - 1, data = dat) 
AICc(m1NAO_NOV_MAR, m2NAO_NOV_MAR)

m1SAH_NOV_MAR <- lm(BKAA ~ SAH_NOV_MAR - 1, data = dat) 
m2SAH_NOV_MAR <- lm(BKAA ~ poly (SAH_NOV_MAR, 2) - 1, data = dat) 
AICc(m1SAH_NOV_MAR, m2SAH_NOV_MAR)

m1IOD_NOV_MAR <- lm(BKAA ~ IOD_NOV_MAR - 1, data = dat) 
m2IOD_NOV_MAR <- lm(BKAA ~ poly (IOD_NOV_MAR, 2) - 1, data = dat) 
AICc(m1IOD_NOV_MAR, m2IOD_NOV_MAR)

m1SOI_NOV_MAR <- lm(BKAA ~ SOI_NOV_MAR - 1, data = dat) 
m2SOI_NOV_MAR <- lm(BKAA ~ poly (SOI_NOV_MAR, 2) - 1, data = dat) 
AICc(m1SOI_NOV_MAR, m2SOI_NOV_MAR)

m1NAO_AUG_OCT <- lm(BKAA ~ NAO_AUG_OCT - 1, data = dat) 
m2NAO_AUG_OCT <- lm(BKAA ~ poly (NAO_AUG_OCT, 2) - 1, data = dat) 
AICc(m1NAO_AUG_OCT, m2NAO_AUG_OCT)

m1SAH_AUG_OCT <- lm(BKAA ~ SAH_AUG_OCT - 1, data = dat) 
m2SAH_AUG_OCT <- lm(BKAA ~ poly (SAH_AUG_OCT, 2) - 1, data = dat) 
AICc(m1SAH_AUG_OCT, m2SAH_AUG_OCT) 

m1IOD_AUG_OCT <- lm(BKAA ~ IOD_AUG_OCT - 1, data = dat) 
m2IOD_AUG_OCT <- lm(BKAA ~ poly (IOD_AUG_OCT, 2) - 1, data = dat) 
AICc(m1IOD_AUG_OCT, m2IOD_AUG_OCT) 

m1SOI_AUG_OCT <- lm(BKAA ~ SOI_AUG_OCT - 1, data = dat) 
m2SOI_AUG_OCT <- lm(BKAA ~ poly (SOI_AUG_OCT, 2) - 1, data = dat) 
AICc(m1SOI_AUG_OCT, m2SOI_AUG_OCT) 

m1NAO_JUN_JUL <- lm(BKAA ~ NAO_JUN_JUL - 1, data = dat) 
m2NAO_JUN_JUL <- lm(BKAA ~ poly (NAO_JUN_JUL, 2) - 1, data = dat) 
AICc(m1NAO_JUN_JUL, m2NAO_JUN_JUL) 

m1SCAND_JUN_JUL  <- lm(BKAA ~ SCAND_JUN_JUL  - 1, data = dat) 
m2SCAND_JUN_JUL  <- lm(BKAA ~ poly (SCAND_JUN_JUL , 2) - 1, data = dat) 
AICc(m1SCAND_JUN_JUL , m2SCAND_JUN_JUL) 

#== MODELS with selected climate variables as quadratic terms ====
#= NAO_JUN_JUL as quadratic term =====
fullmodel.NAO_JUN_JUL2 <- lm(BKAA ~ YearN #Year
                + LEB_APR_MAY + NAO_APR_MAY + SCAND_APR_MAY +  + #condition during spring arrival
                  + NAO_NOV_MAR + SAH_NOV_MAR + IOD_NOV_MAR + SOI_NOV_MAR #conditions non-breeding during stay Nov-Mar
                + NAO_AUG_OCT + SAH_AUG_OCT + IOD_AUG_OCT + SOI_AUG_OCT #conditions during migration south to non-breeding grounds Aug  Oct
                + poly(NAO_JUN_JUL, 2) + SCAND_JUN_JUL 
                - 1 # no Intercept, alternative notation +0#conditions during previous breeding season
                , data = dat) #
summary (fullmodel.NAO_JUN_JUL2)
VIF (fullmodel.NAO_JUN_JUL2)

options(na.action = "na.fail")
results <- dredge(fullmodel.NAO_JUN_JUL2)
# the dredge function fits all combinations
results
names (results)

# best model
subset(results, delta == 0)
# best suppported models with delta AICc < 2
subset(results, delta < 2)

bestmodel.NAO_JUN_JUL2 <- lm (BKAA ~ IOD_AUG_OCT 
                                 + LEB_APR_MAY + NAO_APR_MAY 
                                 + NAO_NOV_MAR + SAH_NOV_MAR 
                                 + SCAND_JUN_JUL + SOI_AUG_OCT -1, data = dat)
#the same best model as in the original submission                             

#= IOD_AUG_OCT as quadratic term =====
fullmodel.IOD_AUG_OCT2 <- lm(BKAA ~ YearN #Year
                + LEB_APR_MAY + NAO_APR_MAY + SCAND_APR_MAY +  + #condition during spring arrival
                + NAO_NOV_MAR + SAH_NOV_MAR + IOD_NOV_MAR + SOI_NOV_MAR #conditions non-breeding during stay Nov-Mar
                + NAO_AUG_OCT + SAH_AUG_OCT + poly (IOD_AUG_OCT,2) + SOI_AUG_OCT #conditions during migration south to non-breeding grounds Aug  Oct
                + NAO_JUN_JUL + SCAND_JUN_JUL 
                - 1 # no Intercept, alternative notation +0#conditions during previous breeding season
                , data = dat) #conditions during previous breeding season
summary (fullmodel.IOD_AUG_OCT2)
VIF (fullmodel.IOD_AUG_OCT2)

options(na.action = "na.fail")
results <- dredge(fullmodel.IOD_AUG_OCT2)
# the dredge function fits all combinations
names (results)

# best model
subset(results, delta == 0)
# best suppported models with delta AICc < 2
subset(results, delta < 2)

bestmodel.IOD_AUG_OCT2 <- lm (BKAA ~ YearN #Year
                  + LEB_APR_MAY + NAO_APR_MAY #condition during spring arrival
                  + SAH_AUG_OCT + poly (IOD_AUG_OCT,2) #conditions during migration south to non-breeding grounds Aug  Oct
                  + SCAND_JUN_JUL 
                  - 1 # no Intercept, alternative notation +0#conditions during previous breeding season
                  , data = dat) #conditions during previous breeding season
summary (bestmodel.IOD_AUG_OCT2)

#= SCAND_JUN_JUL as quadratic term =====
fullmodel.SCAND_JUN_JUL2 <- lm(BKAA ~ YearN #Year
                             + LEB_APR_MAY + NAO_APR_MAY + SCAND_APR_MAY +  + #condition during spring arrival
                             + NAO_NOV_MAR + SAH_NOV_MAR + IOD_NOV_MAR + SOI_NOV_MAR #conditions non-breeding during stay Nov-Mar
                             + NAO_AUG_OCT + SAH_AUG_OCT + IOD_AUG_OCT + SOI_AUG_OCT #conditions during migration south to non-breeding grounds Aug  Oct
                             + NAO_JUN_JUL + poly (SCAND_JUN_JUL, 2) 
                             - 1 # no Intercept, alternative notation +0#conditions during previous breeding season
                             , data = dat) #conditions during previous breeding season
summary (fullmodel.SCAND_JUN_JUL2)
VIF (fullmodel.SCAND_JUN_JUL2)

options(na.action = "na.fail")
results <- dredge(fullmodel.SCAND_JUN_JUL2)
# the dredge function fits all combinations
names (results)

# best model
subset(results, delta == 0)
# best suppported models with delta AICc < 2
subset(results, delta < 2)

bestmodel.SCAND_JUN_JUL2 <- lm (BKAA ~ IOD_AUG_OCT + LEB_APR_MAY + NAO_APR_MAY 
                                + NAO_NOV_MAR + poly(SCAND_JUN_JUL,2)
                                + SAH_NOV_MAR + SOI_AUG_OCT 
                                - 1 # no Intercept, alternative notation +0#conditions during previous breeding season
                             , data = dat) #conditions during previous breeding season
summary (bestmodel.SCAND_JUN_JUL2) 
VIF (bestmodel.SCAND_JUN_JUL2)

#= NAO_AUG_OCT as quadratic term =====
fullmodel.NAO_AUG_OCT2 <- lm(BKAA ~ YearN #Year
                 + LEB_APR_MAY + NAO_APR_MAY + SCAND_APR_MAY +  + #condition during spring arrival
                 + NAO_NOV_MAR + SAH_NOV_MAR + IOD_NOV_MAR + SOI_NOV_MAR #conditions non-breeding during stay Nov-Mar
                 + poly (NAO_AUG_OCT, 2) + SAH_AUG_OCT + IOD_AUG_OCT + SOI_AUG_OCT #conditions during migration south to non-breeding grounds Aug  Oct
                 + NAO_JUN_JUL + SCAND_JUN_JUL 
                 - 1 # no Intercept, alternative notation +0#conditions during previous breeding season
                 , data = dat) #conditions during previous breeding season
summary (fullmodel.NAO_AUG_OCT2)
VIF (fullmodel.NAO_AUG_OCT2)

options(na.action = "na.fail")
results <- dredge(fullmodel.NAO_AUG_OCT2)
# the dredge function fits all combinations
names (results)

# best model
subset(results, delta == 0)
# best suppported models with delta AICc < 2
subset(results, delta < 2)

bestmodel.NAO_AUG_OCT2<- lm (BKAA ~ IOD_AUG_OCT + LEB_APR_MAY 
                  + NAO_APR_MAY + poly(NAO_AUG_OCT,2) 
                  + SCAND_JUN_JUL + SOI_NOV_MAR 
                  - 1 # no Intercept, alternative notation +0#conditions during previous breeding season
                  , data = dat) #conditions during previous breeding season
summary (bestmodel.NAO_AUG_OCT2) 
VIF (bestmodel.NAO_AUG_OCT2)

#=== MODELS USING SUBSETS OF CLIMATE VARIABLES ==== 
fullmodel1 <- lm(BKAA ~ YearN #Year
                 + LEB_APR_MAY + NAO_APR_MAY + SCAND_APR_MAY +  #conditions during spring arrival
                  - 1 # no Intercept, alternative notation +0#conditions during previous breeding season
                 , data = dat) #conditions during previous breeding season
summary (fullmodel1) 
VIF (fullmodel1)  # Variance Inflation Factor


#selects the same best model 1options(na.action = "na.fail")
results <- dredge(fullmodel1)
names (results)
# best model
subset(results, delta == 0)


step(fullmodel1, direction = "backward") 

bestmodel1 <- lm(formula = BKAA ~ LEB_APR_MAY + NAO_APR_MAY - 1, data = dat)
summary (bestmodel1) 
VIF (fullmodel1)  # Variance Inflation Factor
etasq(bestmodel1) #partial R2 coefficient for each factor

fullmodel2 <- lm(BKAA ~ YearN #Year
                 + NAO_NOV_MAR + SAH_NOV_MAR + IOD_NOV_MAR + SOI_NOV_MAR #conditions non-breeding during stay Nov-Mar
                 - 1 # no Intercept, alternative notation +0#conditions during previous breeding season
                 , data = dat) #conditions during previous breeding season
summary (fullmodel2) 
VIF (fullmodel2)  # Variance Inflation Factor


options(na.action = "na.fail")
results <- dredge(fullmodel2)
names (results)
# best model
subset(results, delta == 0)

bestmodel2 <- lm(formula = BKAA ~ IOD_NOV_MAR + NAO_NOV_MAR - 1, data = dat)
summary (bestmodel2) 

VIF (bestmodel2)  # Variance Inflation Factor
etasq(bestmodel2) #partial R2 coefficient for each factor

step(fullmodel2, direction = "backward") 
#selects the same best model 2

fullmodel3 <- lm(BKAA ~ YearN #Year
                 + NAO_AUG_OCT + SAH_AUG_OCT 
                 + IOD_AUG_OCT + SOI_AUG_OCT#conditions during migration south to non-breeding grounds Aug  Oct
                 - 1 # no Intercept, alternative notation +0#conditions during previous breeding season
                 , data = dat) #conditions during previous breeding season
summary (fullmodel3) 
VIF (fullmodel3)  # Variance Inflation Factor

options(na.action = "na.fail")
results <- dredge(fullmodel3)
names (results)
# best model
subset(results, delta == 0)
bestmodel3 <- lm(formula = BKAA ~ IOD_AUG_OCT + SAH_AUG_OCT + SOI_AUG_OCT - 
                   1, data = dat)
summary (bestmodel3) 
VIF (bestmodel3)  # Variance Inflation Factor
etasq(bestmodel3) #partial R2 coefficient for each factor

step(fullmodel3, direction = "backward") 
#selects the same best model 3

fullmodel4 <- lm(BKAA ~ YearN #Year
                 + NAO_JUN_JUL + SCAND_JUN_JUL #conditions at the breeding grounds in summer
                 - 1 # no Intercept, alternative notation +0#conditions during previous breeding season
                 , data = dat) #conditions during previous breeding season
summary (fullmodel4) 
VIF (fullmodel4)  # Variance Inflation Factor

options(na.action = "na.fail")
results <- dredge(fullmodel4)
names (results)
# best model
subset(results, delta == 0)

bestmodel4 <- lm(formula = BKAA ~ SCAND_JUN_JUL - 1, data = dat)
summary (bestmodel4) 
VIF(bestmodel4) 
etasq(bestmodel4) 


step(fullmodel4, direction = "backward")
#selects the same best model 4
 
# final model including best variables from all partial models
bestmodel1 <- lm (BKAA ~ LEB_APR_MAY + NAO_APR_MAY - 1, data = dat)
bestmodel2 <- lm (BKAA ~ NAO_NOV_MAR + IOD_NOV_MAR - 1, data = dat)
bestmodel3 <- lm (BKAA ~ IOD_AUG_OCT + SAH_AUG_OCT + SOI_AUG_OCT - 1, data = dat)
bestmodel4 <- lm (BKAA ~ SCAND_JUN_JUL - 1, data = dat)

full.model1234 <- lm(BKAA ~ LEB_APR_MAY + NAO_APR_MAY 
                         + NAO_NOV_MAR + IOD_NOV_MAR 
                         + IOD_AUG_OCT + SAH_AUG_OCT + SOI_AUG_OCT
                         + SCAND_JUN_JUL - 1, data = dat)
summary (full.model1234)
VIF(full.model1234)

results <- dredge(full.model1234)
names (results)
# best model
subset(results, delta == 0)
best.model1234a <- lm(formula = BKAA ~ 
                        LEB_APR_MAY + NAO_APR_MAY 
                      + IOD_AUG_OCT + SAH_AUG_OCT 
                      + SCAND_JUN_JUL 
                     -  1, data = dat)
summary (best.model1234a) 
VIF (best.model1234a)  # Variance Inflation Factor
etasq(best.model1234a) #partial R2 coefficient for each factor

step(full.model1234, direction = "backward") 
best.model1234b <- lm(formula = BKAA ~ 
                        LEB_APR_MAY + NAO_APR_MAY 
                      + NAO_NOV_MAR 
                      + IOD_AUG_OCT + SAH_AUG_OCT + SOI_AUG_OCT 
                      + SCAND_JUN_JUL 
                      - 1, data = dat)
summary (best.model1234b) 
VIF (best.model1234b)  # Variance Inflation Factor
etasq(best.model1234b) #partial R2 coefficient for each factor
